==> vue-simple-forms-0.2.0.tgz: package/lib/formLeaveGuardMixin.js <==
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.FormLeaveGuardMixin=void 0;function _defineProperty(a,b,c){return b in a?Object.defineProperty(a,b,{value:c,enumerable:!0,configurable:!0,writable:!0}):a[b]=c,a}/**
 * Prevent leaving a route with unsaved changes
 * @param {string|string[]} formKeys            - Form state key(s)
 * @param {Object}          options             - Guard configuration options
 * @param {string}          options.activeKey   - Form leave active state key
 * @param {string}          options.callbackKey - Callback method key
 * @param {boolean}         options.onlyPrevent - Only prevent leaving route (no "active" state)
 * @param {function}        options.onPrevent   - Prevention handler (for custom handling)
 */var FormLeaveGuardMixin=function(a){var b=1<arguments.length&&arguments[1]!==void 0?arguments[1]:{},c=b.activeKey,d=void 0===c?"isLeaveFormActive":c,e=b.callbackKey,f=void 0===e?"formLeaveCallback":e,g=b.onlyPrevent,h=b.onPrevent,i=void 0===h?function(){}:h;return{data:function data(){return _defineProperty({},f,null)},computed:_defineProperty({},d,{get:function get(){return!!this[f]},set:function set(a){var b=this;a||this.$nextTick(function(){b[f]=null})}}),beforeRouteLeave:function beforeRouteLeave(b,c,d){var e=this;// Check all supplied forms for unsaved changes
if("string"==typeof a){var j=checkFormClean.call(this,a);if(j)return d()}else if(Array.isArray(a)){var k=a.every(function(a){return checkFormClean.call(e,a)});if(k)return d()}else return d();// The "onlyPrevent" option only prevents leaving with unsaved data,
//   and does not manage any additional "active" status.
if(void 0!==g&&g)return void(i&&i());/**
       * Callback to determine whether leaving form is allowed
       * @param {boolean} shouldContinue - Whether to leave the form
       */var h=function(){var a=!!(0<arguments.length&&void 0!==arguments[0])&&arguments[0];// Prevent calling twice (from here and "onPrevent" handler)
if(e[f]&&(e[f]=null,a))return d()};// Set the callback and pass the reference to the "onPrevent" callback
this[f]=h,i(h)}}};/**
 * Check whether a form has any unsaved changes
 * @param {string} formKey - Form state key
 */exports.FormLeaveGuardMixin=FormLeaveGuardMixin;function checkFormClean(a){var b=this[a];return!b||!b.flags.changed&&!b.flags.submitting}

==> vue-simple-forms-0.2.1.tgz: package/lib/formLeaveGuardMixin.js <==
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.FormLeaveGuardMixin=void 0;function _defineProperty(a,b,c){return b in a?Object.defineProperty(a,b,{value:c,enumerable:!0,configurable:!0,writable:!0}):a[b]=c,a}/**
 * Prevent leaving a route with unsaved changes
 * @param {string|string[]} formKeys            - Form state key(s)
 * @param {Object}          options             - Guard configuration options
 * @param {string}          options.activeKey   - Form leave active state key
 * @param {string}          options.callbackKey - Callback method key
 * @param {boolean}         options.onlyPrevent - Only prevent leaving route (no "active" state)
 * @param {function}        options.onPrevent   - Prevention handler (for custom handling)
 */var FormLeaveGuardMixin=function(a){var b=1<arguments.length&&arguments[1]!==void 0?arguments[1]:{},c=b.activeKey,d=void 0===c?"isLeaveFormActive":c,e=b.callbackKey,f=void 0===e?"formLeaveCallback":e,g=b.onlyPrevent,h=b.onPrevent,i=void 0===h?function(){}:h;return{data:function data(){return _defineProperty({},f,null)},computed:_defineProperty({},d,{get:function get(){return!!this[f]},set:function set(a){var b=this;a||this.$nextTick(function(){b[f]=null})}}),beforeRouteLeave:function beforeRouteLeave(b,c,d){var e=this;// Check all supplied forms for unsaved changes
if("string"==typeof a){var j=checkFormClean.call(this,a);if(j)return d()}else if(Array.isArray(a)){var k=a.every(function(a){return checkFormClean.call(e,a)});if(k)return d()}else return d();// The "onlyPrevent" option only prevents leaving with unsaved data,
//   and does not manage any additional "active" status.
if(void 0!==g&&g)return void(i&&i());/**
       * Callback to determine whether leaving form is allowed
       * @param {boolean} shouldContinue - Whether to leave the form
       */var h=function(){var b=!!(0<arguments.length&&void 0!==arguments[0])&&arguments[0];// Prevent calling twice (from here and "onPrevent" handler)
if(e[f])return(e[f]=null,b)?(a.forEach(function(a){return resetForm.call(e,a)}),d()):void 0};// Set the callback and pass the reference to the "onPrevent" callback
this[f]=h,i(h)}}};/**
 * Check whether a form has any unsaved changes
 * @param  {string}  formKey - Form state key
 * @return {boolean}         - Whether form is clean
 */exports.FormLeaveGuardMixin=FormLeaveGuardMixin;function checkFormClean(a){var b=this[a];return!b||!b.flags.changed&&!b.flags.submitting}/**
 * Reset a form
 * @param {string} formKey - Form state key
 */function resetForm(a){var b=this[a];b&&b.reset()}
